@@ -1,4 +1,4 @@
-# Copyright (c) 2020, Adrian Dusa
+# Copyright (c) 2019 - 2020, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -29,13 +29,15 @@
     dots <- list(...)
     scollapse <- ifelse(is.element("scollapse", names(dots)), dots$scollapse, FALSE) 
     if (!is.null(noflevels)) {
-        noflevels <- splitstr(noflevels)
-        if (possibleNumeric(noflevels)) {
-            noflevels <- asNumeric(noflevels)
-        }
-        else {
-            cat("\n")
-            stop(simpleError("Invalid number of levels.\n\n"))
+        if (is.character(noflevels)) {
+            noflevels <- splitstr(noflevels)
+            if (possibleNumeric(noflevels)) {
+                noflevels <- asNumeric(noflevels)
+            }
+            else {
+                cat("\n")
+                stop(simpleError("Invalid number of levels.\n\n"))
+            }
         }
     }
     isol <- NULL
@@ -76,9 +78,15 @@
             star <- TRUE
         }
     }
-    mv <- any(grepl("\\[|\\]", input))
-    if (mv) start <- FALSE
-    scollapse <- scollapse | any(nchar(snames) > 1) | mv | star
+    multivalue <- any(grepl("\\[|\\]|\\{|\\}", input))
+    if (multivalue) {
+        start <- FALSE
+        if (is.null(noflevels) | identical(snames, "")) {
+            cat("\n")
+            stop(simpleError("Set names and their number of levels are required to negate multivalue expressions.\n\n"))
+        }
+    }
+    scollapse <- scollapse | any(nchar(snames) > 1) | multivalue | star
     collapse <- ifelse(scollapse, "*", "")
     negateit <- function(x, snames = "", noflevels = NULL, simplify = TRUE, collapse = "*") {
         callist <- list(expression = x)
@@ -98,7 +106,7 @@
             x <- sapply(seq_along(x), function(i) {
                 paste(setdiff(snoflevels[wx][[i]], splitstr(x[i])), collapse = ",")
             })
-            if (mv) {
+            if (multivalue) {
                 return(paste("(", paste(nms, "[", x, "]", sep = "", collapse = " + "), ")", sep = ""))
             }
             else {
